package com.ruoyi.project.sems.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.project.sems.domain.TSpecdevDt;
/**
 * 特种设备电梯台账Mapper接口
 *
 * @author ruoyi
 * @date 2021-07-26
 */
public interface TSpecdevDtMapper
{
    /**
     * 查询特种设备电梯台账
     *
     * @param id 特种设备电梯台账ID
     * @return 特种设备电梯台账
     */
    public TSpecdevDt selectTSpecdevDtById(Long id);

    /**
     * 查询特种设备电梯台账列表
     *
     * @param tSpecdevDt 特种设备电梯台账
     * @return 特种设备电梯台账集合
     */
//    @DataScopePlant(deptAlias = "d")
    public List<TSpecdevDt> selectTSpecdevDtList(TSpecdevDt tSpecdevDt);

    List<TSpecdevDt> selectTSpecdevDtListByYear(TSpecdevDt tSpecdevDt);
    /**
     * 新增特种设备电梯台账
     *
     * @param tSpecdevDt 特种设备电梯台账
     * @return 结果
     */
    public int insertTSpecdevDt(TSpecdevDt tSpecdevDt);

    /**
     * 修改特种设备电梯台账
     *
     * @param tSpecdevDt 特种设备电梯台账
     * @return 结果
     */
    public int updateTSpecdevDt(TSpecdevDt tSpecdevDt);

    /**
     * 删除特种设备电梯台账
     *
     * @param id 特种设备电梯台账ID
     * @return 结果
     */
    public int deleteTSpecdevDtById(Long id);

    /**
     * 批量删除特种设备电梯台账
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecdevDtByIds(Long[] ids);

    void duplicateTSpecdevDt();
}
